@@ -1,10 +1,11 @@
 exams2nops <- function(file, n = 1L, nsamp = NULL, dir = ".", name = NULL,
   language = "en", title = "Exam", course = "",
   institution = "R University", logo = "Rlogo.png", date = Sys.Date(), 
-  replacement = FALSE, intro = NULL, blank = NULL, duplex = TRUE, pages = NULL,
-  usepackage = NULL, header = NULL, encoding = "UTF-8", startid = 1L, points = NULL,
-  showpoints = FALSE, samepage = FALSE, newpage = FALSE, twocolumn = FALSE, helvet = TRUE,
-  reglength = 7L, seed = NULL, ...)
+  replacement = FALSE, shortquiz = FALSE, intro = NULL, blank = NULL,
+  duplex = TRUE, pages = NULL, usepackage = NULL, header = NULL,
+  reglength = 7L, startid = 1L, points = NULL,
+  showpoints = FALSE, samepage = FALSE, newpage = FALSE, filbreak = FALSE, twocolumn = FALSE,
+  helvet = TRUE, seed = NULL, ..., encoding = "UTF-8")
 {
   ## handle matrix specification of file
   if(is.matrix(file)) {
@@ -132,8 +133,8 @@ exams2nops <- function(file, n = 1L, nsamp = NULL, dir = ".", name = NULL,
     replacement = replacement, intro = intro, blank = blank,
     duplex = duplex, pages = pages, file = template,
     nchoice = nchoice,
-    encoding = encoding, samepage = samepage, newpage = newpage, twocolumn = twocolumn,
-    helvet = helvet, reglength = reglength)
+    encoding = encoding, samepage = samepage, newpage = newpage, filbreak = filbreak, twocolumn = twocolumn,
+    helvet = helvet, reglength = reglength, shortquiz = shortquiz)
 
   ## if points should be shown generate a custom transformer
   transform <- if(showpoints) {
@@ -171,12 +172,20 @@ exams2nops <- function(file, n = 1L, nsamp = NULL, dir = ".", name = NULL,
   invisible(rval)
 }
 
-make_nops_template <- function(n, replacement = FALSE, intro = NULL, blank = NULL,
-  duplex = TRUE, pages = NULL, file = NULL, nchoice = 5, encoding = "UTF-8",
-  samepage = FALSE, newpage = FALSE, twocolumn = FALSE, helvet = TRUE, reglength = 7L)
+make_nops_template <- function(n, replacement = FALSE, shortquiz = FALSE,
+  intro = NULL, blank = NULL, duplex = TRUE, pages = NULL, file = NULL,
+  nchoice = 5, reglength = 7L, samepage = FALSE, newpage = FALSE, filbreak = FALSE, twocolumn = FALSE,
+  helvet = TRUE, encoding = "UTF-8")
 {
 
-page1 <- make_nops_page(n, nchoice = nchoice, reglength = reglength)
+if(shortquiz) {
+  if(n > 3L || replacement || any(nchoice < 1L) || !is.null(intro) || !is.null(pages)) {
+    stop("'shortquiz' currently only supports single-page exam sheets with up to 3 schoice/mchoice questions")
+  }
+  duplex <- FALSE
+}
+
+page1 <- make_nops_page(n, nchoice = nchoice, reglength = reglength, shortquiz = shortquiz)
 page2 <- if(replacement) {
   make_nops_page(n, nchoice = nchoice, replacement = TRUE, reglength = reglength)
 } else {
@@ -195,12 +204,6 @@ addreg <- pmin(3L, pmax(0L, reglength - 7L))
 if(!is.null(encoding) && !(tolower(encoding) %in% c("", "utf-8", "utf8"))) {
   warning("the only supported 'encoding' is UTF-8")
 }
-encoding <- "UTF-8"
-
-## legacy code for other encodings
-enc <- gsub("-", "", tolower(encoding), fixed = TRUE)
-if(enc %in% c("iso8859", "iso88591")) enc <- "latin1"
-if(enc == "iso885915") enc <- "latin9"
 
 ## intro text (if any)
 if(!is.null(intro) && length(intro) == 1L && all(tools::file_ext(intro) == "tex")) intro <- readLines(intro)
@@ -241,7 +244,6 @@ sprintf("\\documentclass[10pt,a4paper%s]{article}", if(twocolumn) ",twocolumn" e
 \\newenvironment{Schunk}{}{}
 
 \\usepackage[T1]{fontenc}",
-if(enc != "") sprintf('\\usepackage[%s]{inputenc}', enc) else NULL,
 if(helvet) "
 \\usepackage{helvet}
 \\IfFileExists{sfmath.sty}{
@@ -343,17 +345,16 @@ sprintf("\\reg%s%s", c("seven", "eight", "nine", "ten"), tolower(0L:3L == addreg
 \\newcounter{nopsitem}
 \\newenvironment{solution}{\\comment}{\\endcomment}",
 
-if(newpage) {
-  "\\newenvironment{question}{\\item}{\\newpage}"
-} else {
-  "\\newenvironment{question}{\\item}{}"
-},
+sprintf("\\newenvironment{question}{%s\\item}{%s}",
+  if(filbreak) "\\filbreak" else "",
+  if(newpage) "\\newpage" else ""
+),
+
+sprintf("\\newenvironment{answerlist}{\\renewcommand{\\labelenumii}{\\alph{enumii}.}%s\\begin{enumerate}}{\\end{enumerate}%s}",
+  if(samepage) "\\begin{samepage}" else "",
+  if(samepage) "\\end{samepage}" else ""
+),
 
-if(samepage) {
-  "\\newenvironment{answerlist}{\\renewcommand{\\labelenumii}{\\alph{enumii}.}\\begin{samepage}\\begin{enumerate}}{\\end{enumerate}\\end{samepage}}"
-} else {
-  "\\newenvironment{answerlist}{\\renewcommand{\\labelenumii}{\\alph{enumii}.}\\begin{enumerate}}{\\end{enumerate}}"
-},
 
 "
 %% additional header commands
@@ -485,6 +486,9 @@ if(length(page3)) {
 \\setlength{\\headsep}{1cm} 
 \\setlength{\\footskip}{1cm} 
 
+",
+
+if(!shortquiz) c("
 \\newpage
 ",
 
@@ -505,6 +509,9 @@ blank[[2L]],
 "
 \\newpage
 
+"),
+
+"
 \\end{document}
 ")
 
@@ -514,7 +521,7 @@ if(!is.null(file)) writeLines(rval, file)
 invisible(rval)
 }
 
-make_nops_page <- function(n, replacement = FALSE, nchoice = 5, reglength = 7L)
+make_nops_page <- function(n, replacement = FALSE, nchoice = 5, reglength = 7L, shortquiz = FALSE)
 {
 ## length of registration ID
 if(reglength < 7L) {
@@ -683,7 +690,7 @@ sapply(1:n, function(i) qbox(i, nchoice = nchoice[i])),
 \\linethickness{0.5mm} \\put(20,164){\\framebox(\\namewidth,28){}} \\thicklines  
 \\put(32,177){\\makebox(0,0)[t]{\\textsf{\\myDocumentType}}} 
 \\put(25,166){\\framebox(14,7){}} 
-\\put(67,177){\\makebox(0,0)[t]{\\textsf{\\myDocumentID \\mycourse}}}
+\\put(67,177){\\makebox(0,0)[t]{\\textsf{{\\myDocumentID} {\\mycourse}}}}
 \\put(46,166){\\framebox(42,7){}} \\put(25,183.5){\\parbox{70mm}{%
 \\textsf{\\myNoChanges}}}
 \\ifregseven
@@ -711,6 +718,27 @@ if(replacement & addreg == 0L) {
 "
 },
 
+## single-page version?
+if(shortquiz) {
+sprintf("
+%% questions on exam sheet
+\\newcounter{nopsquestion}
+\\renewenvironment{question}{\\stepcounter{nopsquestion}\\arabic{nopsquestion}.}{}
+\\renewenvironment{answerlist}{\\renewcommand{\\labelenumi}{\\alph{enumi}.}%%
+\\begin{multicols}{%s}%%
+\\begin{enumerate}}{\\end{enumerate}%%
+\\end{multicols}%%
+}
+
+\\put(20,20){\\parbox[b]{170mm}{
+
+%%%% \\exinput{exercises}
+
+}} 
+", max(nchoice))
+},
+
+
 "
 \\end{picture}
 ")
